@@ -1,13 +1,12 @@
 import re
 from string import punctuation
 
-reg_punc = re.compile("[%s]" % re.escape(punctuation))
+reg_punc = re.compile(f"[{re.escape(punctuation)}]")
 combined_whitespace = re.compile(r"\s{2,}")
 
 
 def strip_punc(court_str: str) -> str:
     """Remove whitespace from court_str.
-
     :param: court_str: The court string
     :return: The court string without extra whitespace
     """
